
# extrude
Tool to run a composite web application to easily interact with python functions


To install:	```pip install extrude```

See [examples here](https://github.com/i2mint/extrude/tree/master/extrude/examples).
